#ifndef NT2_INCLUDE_CONSTANTS_FIFTEEN_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_FIFTEEN_HPP_INCLUDED

#include <nt2/constant/include/constants/fifteen.hpp>

#endif
